aboutsummaryrefslogtreecommitdiffstats
path: root/yardstick/benchmark/core/plugin.py
diff options
context:
space:
mode:
Diffstat (limited to 'yardstick/benchmark/core/plugin.py')
-rw-r--r--yardstick/benchmark/core/plugin.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/yardstick/benchmark/core/plugin.py b/yardstick/benchmark/core/plugin.py
index 7f67a04b3..6c06767d5 100644
--- a/yardstick/benchmark/core/plugin.py
+++ b/yardstick/benchmark/core/plugin.py
@@ -84,8 +84,8 @@ class Plugin(object):
if deployment_ip == "local":
self.client = ssh.SSH.from_node(deployment, overrides={
- # host can't be None, fail if no INSTALLER_IP
- 'ip': os.environ["INSTALLER_IP"],
+ # host can't be None, fail if no JUMP_HOST_IP
+ 'ip': os.environ["JUMP_HOST_IP"],
})
else:
self.client = ssh.SSH.from_node(deployment)